(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5714,        188]*)
(*NotebookOutlinePosition[      6420,        213]*)
(*  CellTagsIndexPosition[      6376,        209]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " file is intended for showing how to call  a java class, SheppLogan3D, \
from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".\nIf you have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5 or above, you should have JLink installed otherwise you have download \
JLink from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " website.  \nIn ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5 or above, it comes with Java Runtime Environment (JRE) but you can \
specify different version of Java by setting one of the options in \
InstallJava, which is what I have done here."
}], "Text"],

Cell[BoxData[{
    \(Off[General::spell]\), "\[IndentingNewLine]", 
    \(Off[General::spell1]\)}], "Input"],

Cell[BoxData[
    \(\(\( (*Load\ JLink\ *) \)\(\[IndentingNewLine]\)\(Needs["\<JLink`\>"]\)\
\)\)], "Input"],

Cell["\<\
Note that each directory in ClassPath is separated by \";\", it is true for \
Windows only. For Linux, you have to use \":\". 
One of the directory in classpath should point to the STBB.jar.   \
\>", "Text"],

Cell[BoxData[
    \(\(\( (*Example : \ 
        For\ Windows*) \)\(\[IndentingNewLine]\)\(InstallJava[\
\[IndentingNewLine]CommandLine \[Rule] "\<C:\\java\\j2sdk142\\bin\\java.exe \
-Xmx600m\>", 
        ClassPath \[Rule] "\<.;C:\\Documents and Settings\\Cheng Guan \
Koay\\Desktop\\3DNumericalPhantom\\PublicRelease\\STBBFolder\\JarFile\\STBB.\
jar\>"\ ];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*Example : \ 
        For\ Linux*) \)\(\[IndentingNewLine]\)\(InstallJava[\
\[IndentingNewLine]CommandLine \[Rule] "\</home/java/j2sdk5.0/bin/java \
-Xmx600m\>", 
        ClassPath \[Rule] "\<.:/home/STBBFolder/JarFile/STBB.jar\>"];\)\)\)], \
"Input"],

Cell["Load Java class:", "Text"],

Cell[BoxData[
    \(\(SL3D = LoadJavaClass["\<STBB.SheppLogan3D\>"];\)\)], "Input"],

Cell["Create a Java object based on SL3D:", "Text"],

Cell[BoxData[
    \(\(aSL3DObject\  = \ JavaNew[SL3D];\)\)], "Input"],

Cell["Basic set up", "Text"],

Cell[BoxData[{
    \(\(x = \(-0.25\);\)\), "\[IndentingNewLine]", 
    \(\(y = 0.15;\)\), "\[IndentingNewLine]", 
    \(\(z = 0.05;\)\), "\[IndentingNewLine]", 
    \(\(kx = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(ky = 0.15;\)\), "\[IndentingNewLine]", 
    \(\(kz = 0.05;\)\)}], "Input"],

Cell["Image Domain signal at (-0.25,0.15,0.05)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(aSL3DObject@ImageDomainSignal[x, y, z]\)], "Input"],

Cell[BoxData[
    \(1.2`\)], "Output"]
}, Open  ]],

Cell["Fourier Domain signal at (0.25,0.15,0.05)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \(({1, I}*
          aSL3DObject@FourierDomainSignal[kx, ky, kz])\)\)], "Input"],

Cell[BoxData[
    \(\(\(2.4834061312960225`\)\(\[InvisibleSpace]\)\) - 
      0.00838733761651407`\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell["image domain signals at  {{-0.25,0.15,0.05},{0.5,0.35,0.5}} ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\ \(r\  = \ {{\(-0.25\), 0.15, 0.05}, {0.5, 0.35, 
            0.5}};\)\), "\[IndentingNewLine]", 
    \(aSL3DObject@ImageDomainSignal[r]\)}], "Input"],

Cell[BoxData[
    \({1.2`, 2.`}\)], "Output"]
}, Open  ]],

Cell["\<\
Fourier domain signals at  {{-0.25,0.15,0.05},{0.75,0.5,0.5}} \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(k\  = \ \ {{\(-0.25\), 0.15, 0.05}, {0.75, 0.5, 
            0.5}};\)\), "\[IndentingNewLine]", 
    \(Apply[
      Plus, \((\(Times[{1, I}, #] &\) /@ 
          aSL3DObject@FourierDomainSignal[k])\), {1}]\)}], "Input"],

Cell[BoxData[
    \({\(\(2.48331915292207`\)\(\[InvisibleSpace]\)\) - 
        0.004916488124360764`\ \[ImaginaryI], \(-0.22797836078897474`\) - 
        0.012638899072246745`\ \[ImaginaryI]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(UninstallJava[]\)], "Input"],

Cell[BoxData[
    \("C:\\java\\j2sdk142\\bin\\java.exe"\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 727}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1094, 631},
WindowMargins->{{18, Automatic}, {Automatic, 23}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 711, 21, 71, "Text"],
Cell[2431, 72, 108, 2, 50, "Input"],
Cell[2542, 76, 108, 2, 50, "Input"],
Cell[2653, 80, 217, 4, 52, "Text"],
Cell[2873, 86, 373, 7, 90, "Input"],
Cell[3249, 95, 277, 6, 70, "Input"],
Cell[3529, 103, 32, 0, 33, "Text"],
Cell[3564, 105, 83, 1, 30, "Input"],
Cell[3650, 108, 51, 0, 33, "Text"],
Cell[3704, 110, 69, 1, 30, "Input"],
Cell[3776, 113, 28, 0, 33, "Text"],
Cell[3807, 115, 291, 6, 130, "Input"],
Cell[4101, 123, 56, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[4182, 127, 71, 1, 30, "Input"],
Cell[4256, 130, 38, 1, 29, "Output"]
}, Open  ]],
Cell[4309, 134, 57, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[4391, 138, 108, 2, 30, "Input"],
Cell[4502, 142, 127, 2, 29, "Output"]
}, Open  ]],
Cell[4644, 147, 76, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[4745, 151, 172, 3, 50, "Input"],
Cell[4920, 156, 45, 1, 29, "Output"]
}, Open  ]],
Cell[4980, 160, 86, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[5091, 166, 242, 5, 50, "Input"],
Cell[5336, 173, 205, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5578, 181, 48, 1, 30, "Input"],
Cell[5629, 184, 69, 1, 29, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

